/*
 * jkeytool - CoreListenerSupport.java -
 * Copyright © 2009 David Roden
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package net.pterodactylus.jkeytool.core;

import java.io.File;
import java.security.KeyStore;

import de.ina.util.event.AbstractListenerSupport;

/**
 * Helper class to fire {@link CoreListener} events to registered listeners.
 *
 * @author David Roden &lt;droden@gmail.com&gt;
 */
public class CoreListenerSupport extends AbstractListenerSupport<Core, CoreListener> {

	/**
	 * Creates a new core listener support.
	 *
	 * @param source
	 *            The event-emitting core
	 */
	public CoreListenerSupport(Core source) {
		super(source);
	}

	//
	// EVENT METHODS
	//

	/**
	 * Notifies all listeners that a new key store was created.
	 *
	 * @see CoreListener#keyStoreCreated(KeyStore)
	 * @param keyStore
	 *            The key store that was created
	 */
	public void fireKeyStoreCreated(KeyStore keyStore) {
		for (CoreListener coreListener : getListeners()) {
			coreListener.keyStoreCreated(keyStore);
		}
	}

	/**
	 * Notifies all listeners that a key store could not be created.
	 *
	 * @param keyStoreType
	 *            The type of the key store
	 * @param reason
	 *            The reason why the key store could not be created
	 */
	public void fireKeyStoreNotCreated(String keyStoreType, Throwable reason) {
		for (CoreListener coreListener : getListeners()) {
			coreListener.keyStoreNotCreated(keyStoreType, reason);
		}
	}

	/**
	 * Notifies all listeners that a keystore was loaded from a file.
	 *
	 * @see CoreListener#keyStoreLoaded(File, KeyStore)
	 * @param keyStoreFile
	 *            The keystore file
	 * @param keyStore
	 *            The loaded keystore
	 */
	public void fireKeyStoreLoaded(File keyStoreFile, KeyStore keyStore) {
		for (CoreListener coreListener : getListeners()) {
			coreListener.keyStoreLoaded(keyStoreFile, keyStore);
		}
	}

	/**
	 * Notifies all listeners that a keystore could not be loaded from a file.
	 *
	 * @param keyStoreFile
	 *            The keystore file
	 */
	public void fireKeyStoreNotLoaded(File keyStoreFile) {
		for (CoreListener coreListener : getListeners()) {
			coreListener.keyStoreNotLoaded(keyStoreFile);
		}
	}

}
